@@ -107,6 +107,10 @@ class HyperVDriver(driver.ComputeDriver):
         "supports_extend_volume": True,
         "supports_multiattach": False,
         "supports_trusted_certs": True,
+
+        # Supported image types
+        "supports_image_type_vhd": True,
+        "supports_image_type_vhdx": True,
     }
 
     use_coordination = False
@@ -116,6 +120,11 @@ class HyperVDriver(driver.ComputeDriver):
         # further driver initialisation.
         self._check_minimum_windows_version()
 
+        # We'll initialize coordination as early as possible, avoiding
+        # the risk of using locks before the mechanism is enabled.
+        if self.use_coordination:
+            coordination.COORDINATOR.start()
+
         super(HyperVDriver, self).__init__(virtapi)
 
         self._hostops = hostops.HostOps()
@@ -154,9 +163,6 @@ class HyperVDriver(driver.ComputeDriver):
         return False
 
     def init_host(self, host):
-        if self.use_coordination:
-            coordination.COORDINATOR.start()
-
         self._serialconsoleops.start_console_handlers()
 
         self._set_event_handler_callbacks()
@@ -177,15 +183,13 @@ class HyperVDriver(driver.ComputeDriver):
     def list_instances(self):
         return self._vmops.list_instances()
 
-    def estimate_instance_overhead(self, instance_info):
-        return self._vmops.estimate_instance_overhead(instance_info)
-
     def spawn(self, context, instance, image_meta, injected_files,
               admin_password, allocations, network_info=None,
-              block_device_info=None):
+              block_device_info=None, power_on=True):
         image_meta = self._recreate_image_meta(context, instance, image_meta)
         self._vmops.spawn(context, instance, image_meta, injected_files,
-                          admin_password, network_info, block_device_info)
+                          admin_password, network_info, block_device_info,
+                          power_on)
 
     def reboot(self, context, instance, network_info, reboot_type,
                block_device_info=None, bad_volumes_callback=None):
@@ -370,7 +374,8 @@ class HyperVDriver(driver.ComputeDriver):
                                              instance, network_info)
 
     def finish_revert_migration(self, context, instance, network_info,
-                                block_device_info=None, power_on=True):
+                                migration, block_device_info=None,
+                                power_on=True):
         self._migrationops.finish_revert_migration(context, instance,
                                                    network_info,
                                                    block_device_info, power_on)
@@ -456,3 +461,10 @@ class HyperVDriver(driver.ComputeDriver):
 
     def check_instance_shared_storage_cleanup(self, context, data):
         return self._pathutils.check_instance_shared_storage_cleanup(data)
+
+    def update_provider_tree(self, provider_tree, nodename, allocations=None):
+        inventory = provider_tree.data(nodename).inventory
+        alloc_ratios = self._get_allocation_ratios(inventory)
+
+        self._hostops.update_provider_tree(
+            provider_tree, nodename, alloc_ratios, allocations)
