@@ -146,7 +146,7 @@ class ClusterOpsTestCase(test_base.HyperVBaseTestCase):
             self.clusterops._vmops.list_instance_uuids.return_value)
         mock_spawn.assert_called_once_with(
             mock_failover_migrate,
-            mock_instance1.name, mock_instance1.host,
+            mock_instance1.name,
             self.clusterops._this_node)
 
     @mock.patch.object(clusterops.ClusterOps, '_wait_for_pending_instance')
@@ -178,7 +178,9 @@ class ClusterOpsTestCase(test_base.HyperVBaseTestCase):
                                           'new_host')
 
         mock_LOG.debug.assert_called_once_with(
-            'Instance %s is live migrating.', mock.sentinel.instance_name)
+            'Instance %s is being migrated by Nova. This '
+            'will not be treated as a failover.',
+            mock.sentinel.instance_name)
 
     @mock.patch.object(clusterops.ClusterOps, '_wait_for_pending_instance')
     @mock.patch.object(clusterops.ClusterOps, '_get_instance_by_name')
@@ -250,6 +252,9 @@ class ClusterOpsTestCase(test_base.HyperVBaseTestCase):
         c_handler = self.clusterops._serial_console_ops.start_console_handler
         c_handler.assert_called_once_with(mock.sentinel.instance_name)
 
+    @ddt.data({},
+              {'recreate_ports_on_failover': True})
+    @ddt.unpack
     @mock.patch.object(clusterops.ClusterOps, '_wait_for_pending_instance')
     @mock.patch.object(clusterops.ClusterOps, '_failover_migrate_networks')
     @mock.patch.object(clusterops.ClusterOps, '_nova_failover_server')
@@ -257,10 +262,14 @@ class ClusterOpsTestCase(test_base.HyperVBaseTestCase):
     def test_failover_same_node(self, mock_get_instance_by_name,
                                 mock_nova_failover_server,
                                 mock_failover_migrate_networks,
-                                mock_wait_pending_instance):
+                                mock_wait_pending_instance,
+                                recreate_ports_on_failover=False):
         # In some cases, the instances may bounce between hosts. We're testing
         # the case in which the instance is actually returning to the initial
         # host during the time in which we're processing events.
+        self.flags(recreate_ports_on_failover=recreate_ports_on_failover,
+                   group='hyperv')
+
         instance = mock_get_instance_by_name.return_value
         old_host = 'old_host'
         new_host = 'new_host'
@@ -275,7 +284,11 @@ class ClusterOpsTestCase(test_base.HyperVBaseTestCase):
         get_inst_nw_info.assert_called_once_with(self.clusterops._context,
                                                  instance)
         mock_nova_failover_server.assert_called_once_with(instance, old_host)
-        self.clusterops._vmops.unplug_vifs.assert_not_called()
+        if recreate_ports_on_failover:
+            self.clusterops._vmops.unplug_vifs.assert_called_once_with(
+                instance, get_inst_nw_info.return_value)
+        else:
+            self.clusterops._vmops.unplug_vifs.assert_not_called()
         self.clusterops._vmops.plug_vifs.assert_called_once_with(
             instance, get_inst_nw_info.return_value)
         self._placement.move_compute_node_allocations.assert_not_called()
@@ -317,7 +330,8 @@ class ClusterOpsTestCase(test_base.HyperVBaseTestCase):
         mock_network_api.migrate_instance_start.assert_called_once_with(
             self.clusterops._context, mock_instance, fake_migration)
         mock_network_api.migrate_instance_finish.assert_called_once_with(
-            self.clusterops._context, mock_instance, fake_migration)
+            self.clusterops._context, mock_instance, fake_migration,
+            provider_mappings=None)
 
     @mock.patch.object(objects.Instance, 'get_by_uuid')
     def test_get_instance_by_name(self, mock_get_by_uuid):
