@@ -22,6 +22,7 @@ import sys
 
 import mock
 from nova import exception
+from nova.image import api
 from nova import safe_utils
 from nova.tests.unit import fake_instance
 from nova.virt import driver as base_driver
@@ -34,6 +35,7 @@ from compute_hyperv.tests.unit import test_base
 class HyperVDriverTestCase(test_base.HyperVBaseTestCase):
 
     _autospec_classes = [
+        driver.eventhandler.InstanceEventHandler,
         driver.hostops.HostOps,
         driver.volumeops.VolumeOps,
         driver.vmops.VMOps,
@@ -43,8 +45,8 @@ class HyperVDriverTestCase(test_base.HyperVBaseTestCase):
         driver.rdpconsoleops.RDPConsoleOps,
         driver.serialconsoleops.SerialConsoleOps,
         driver.imagecache.ImageCache,
-        driver.image.API,
         driver.pathutils.PathUtils,
+        api.API,
     ]
 
     FAKE_WIN_2008R2_VERSION = '6.0.0'
@@ -123,9 +125,7 @@ class HyperVDriverTestCase(test_base.HyperVBaseTestCase):
             # original frame will contain the 'foo' variable.
             self.assertEqual('foofoo', trace.tb_frame.f_locals['foo'])
 
-    @mock.patch.object(driver.eventhandler, 'InstanceEventHandler')
-    def test_init_host(self, mock_InstanceEventHandler):
-
+    def test_init_host(self):
         mock_get_inst_dir = self.driver._pathutils.get_instances_dir
         mock_get_inst_dir.return_value = mock.sentinel.FAKE_DIR
 
@@ -134,10 +134,10 @@ class HyperVDriverTestCase(test_base.HyperVBaseTestCase):
         mock_start_console_handlers = (
             self.driver._serialconsoleops.start_console_handlers)
         mock_start_console_handlers.assert_called_once_with()
-        mock_InstanceEventHandler.assert_called_once_with(
-            state_change_callback=self.driver.emit_event)
-        fake_event_handler = mock_InstanceEventHandler.return_value
-        fake_event_handler.start_listener.assert_called_once_with()
+        self.driver._event_handler.add_callback.assert_has_calls(
+            [mock.call(self.driver.emit_event),
+             mock.call(self.driver._vmops.instance_state_change_callback)])
+        self.driver._event_handler.start_listener.assert_called_once_with()
 
         mock_get_inst_dir.assert_called_once_with()
         self.driver._pathutils.check_create_dir.assert_called_once_with(
@@ -151,11 +151,6 @@ class HyperVDriverTestCase(test_base.HyperVBaseTestCase):
         self.driver.list_instances()
         self.driver._vmops.list_instances.assert_called_once_with()
 
-    def test_estimate_instance_overhead(self):
-        self.driver.estimate_instance_overhead(mock.sentinel.instance)
-        self.driver._vmops.estimate_instance_overhead.assert_called_once_with(
-            mock.sentinel.instance)
-
     @mock.patch.object(driver.HyperVDriver, '_recreate_image_meta')
     def test_spawn(self, mock_recreate_img_meta):
         self.driver.spawn(
@@ -163,7 +158,8 @@ class HyperVDriverTestCase(test_base.HyperVBaseTestCase):
             mock.sentinel.image_meta, mock.sentinel.injected_files,
             mock.sentinel.admin_password, mock.sentinel.allocations,
             mock.sentinel.network_info,
-            mock.sentinel.block_device_info)
+            mock.sentinel.block_device_info,
+            mock.sentinel.power_on)
 
         mock_recreate_img_meta.assert_called_once_with(
             mock.sentinel.context, mock.sentinel.instance,
@@ -172,7 +168,8 @@ class HyperVDriverTestCase(test_base.HyperVBaseTestCase):
             mock.sentinel.context, mock.sentinel.instance,
             mock_recreate_img_meta.return_value, mock.sentinel.injected_files,
             mock.sentinel.admin_password, mock.sentinel.network_info,
-            mock.sentinel.block_device_info)
+            mock.sentinel.block_device_info,
+            mock.sentinel.power_on)
 
     def test_reboot(self):
         self.driver.reboot(
@@ -239,7 +236,8 @@ class HyperVDriverTestCase(test_base.HyperVBaseTestCase):
     def test_extend_volume(self):
         mock_instance = fake_instance.fake_instance_obj(self.context)
         self.driver.extend_volume(
-            mock.sentinel.connection_info, mock_instance)
+            mock.sentinel.connection_info, mock_instance,
+            mock.sentinel.requested_size)
 
         self.driver._volumeops.extend_volume.assert_called_once_with(
             mock.sentinel.connection_info)
@@ -485,8 +483,8 @@ class HyperVDriverTestCase(test_base.HyperVBaseTestCase):
     def test_finish_revert_migration(self):
         self.driver.finish_revert_migration(
             mock.sentinel.context, mock.sentinel.instance,
-            mock.sentinel.network_info, mock.sentinel.block_device_info,
-            mock.sentinel.power_on)
+            mock.sentinel.network_info, mock.sentinel.migration,
+            mock.sentinel.block_device_info, mock.sentinel.power_on)
 
         finish_revert_migr = self.driver._migrationops.finish_revert_migration
         finish_revert_migr.assert_called_once_with(
@@ -629,3 +627,17 @@ class HyperVDriverTestCase(test_base.HyperVBaseTestCase):
 
         self.assertEqual(check_cleanup.return_value, ret_val)
         check_cleanup.assert_called_once_with(mock.sentinel.data)
+
+    @mock.patch.object(driver.HyperVDriver, '_get_allocation_ratios')
+    def test_update_provider_tree(self, mock_get_alloc_ratios):
+        mock_ptree = mock.Mock()
+        mock_inventory = mock_ptree.data.return_value.inventory
+
+        self.driver.update_provider_tree(
+            mock_ptree, mock.sentinel.nodename, mock.sentinel.allocations)
+
+        mock_get_alloc_ratios.assert_called_once_with(mock_inventory)
+        self.driver._hostops.update_provider_tree.assert_called_once_with(
+            mock_ptree, mock.sentinel.nodename,
+            mock_get_alloc_ratios.return_value,
+            mock.sentinel.allocations)
